Package: dcanr
Title: Differential co-expression/association network analysis
Version: 1.20.0
Authors@R: person("Dharmesh", "Bhuva", "D.", email = "bhuva.d@wehi.edu.au", role = c("aut", "cre"), comment = c(ORCID = '0000-0002-6398-9157'))
Description: This package implements methods and an evaluation framework to infer differential co-expression/association networks. Various methods are implemented and can be evaluated using simulated datasets. Inference of differential co-expression networks can allow identification of networks that are altered between two conditions (e.g., health and disease).
biocViews: NetworkInference, GraphAndNetwork, DifferentialExpression,
        Network
Depends: R (>= 3.6.0)
License: GPL-3
Encoding: UTF-8
LazyData: false
Imports: igraph, foreach, plyr, stringr, reshape2, methods, Matrix,
        graphics, stats, RColorBrewer, circlize, doRNG
Suggests: EBcoexpress, testthat, EBarrays, GeneNet, mclust, minqa,
        SummarizedExperiment, Biobase, knitr, rmarkdown, BiocStyle,
        edgeR
RoxygenNote: 7.2.0
Collate: 'LDGM.R' 'dcZscore.R' 'dcanr.R' 'statistical_tests.R'
        'performance_metrics.R' 'multtest_adjust.R'
        'evaluation_functions.R' 'inference_methods.R'
        'inference_methods_generic.R' 'network_inference.R' 'sim102.R'
        'simulation_accessors.R' 'simulation_plot.R'
VignetteBuilder: knitr
Enhances: parallel, doSNOW, doParallel
URL: https://davislaboratory.github.io/dcanr/,
        https://github.com/DavisLaboratory/dcanr
BugReports: https://github.com/DavisLaboratory/dcanr/issues
git_url: https://git.bioconductor.org/packages/dcanr
git_branch: RELEASE_3_19
git_last_commit: 46cf53e
git_last_commit_date: 2024-04-30
Repository: Bioconductor 3.19
Date/Publication: 2024-04-30
NeedsCompilation: no
Packaged: 2024-05-01 03:22:33 UTC; biocbuild
Author: Dharmesh D. Bhuva [aut, cre] (<https://orcid.org/0000-0002-6398-9157>)
Maintainer: Dharmesh D. Bhuva <bhuva.d@wehi.edu.au>
Built: R 4.4.0; ; 2024-05-07 04:33:24 UTC; unix
