# Generated by roxygen2: do not edit by hand

export(cor.pairs)
export(dcAdjust)
export(dcEvaluate)
export(dcMethods)
export(dcNetwork)
export(dcPipeline)
export(dcTest)
export(dcZscore)
export(getConditionNames)
export(getSimData)
export(getTrueNetwork)
export(mi.ap)
export(perfMethods)
export(performanceMeasure)
export(plotSimNetwork)
exportMethods(dcScore)
import(methods)
importFrom(doRNG,"%dorng%")
importFrom(foreach,"%:%")
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(graphics,par)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(stats,anova)
importFrom(stats,binomial)
importFrom(stats,glm)
importFrom(stats,p.adjust)
importFrom(stats,pnorm)
importFrom(stats,qchisq)
importFrom(stats,var)
